*=============================================
* ad8158_test.sp -- HSPICE Simulation
*
* This file provides a simulation example
* using the AD8158 HSPICE RX and TX models.
*
* Revision 2.0: 1/5/2009
* Revision 1.0: 7/7/2006
*=============================================

.include "ad8158_model.inc"
.include "ad8158_lineloss.inc"

* Receiver model
xrx ip in xp xn vtti vcc vee 
+ ad8158_rx setting=ad8158_eq_setting

* Intermediate resistors - used to couple RX/TX and provide internal "test-point"
* for viewing effects of EQ setting
rxn xn vcc R=1k
rxp xp vcc R=1k

* Transmitter model
xtx xp xn op on vtto vee ad8158_tx
+ olev=ad8158_tx_olev  pe_boost=ad8158_pe_boost
+ sel4g=ad8158_sel4g


* Define Supply Voltages
VTTI vtti 0 DC=1.8 AC=0, 0
VTTO vtto 0 DC=1.8 AC=0, 0
VCC vcc 0 DC=1.8 AC=0, 0
VEE vee 0 DC=0   AC=0, 0

* PRBS input pattern
VSRCP vip vee LFSR (1.0 1.8 1n 15p 15p 6.5G 1 [11, 2] rout=50)
VSRCN vin vee LFSR (1.8 1.0 1n 15p 15p 6.5G 1 [11, 2] rout=50)

* PRBS filter -- Removes the discontinuity present in all derivatives
* of the input signal.  Essentially a low-pass filter.

xprbsfiltp vip vip1 adi_prbs_filter tau=15p
xprbsfiltn vin vin1 adi_prbs_filter tau=15p

* Input Loss Model Inserted Between vip1,vin1 // vip2,vin2

.param linelength_in = 10	$ input line length in inches
xinlinep vip1 ip vtti ad8158_lineloss linelength=linelength_in
xinlinen vin1 in vtti ad8158_lineloss linelength=linelength_in

* Output Loss Model Inserted Between op,on // outp,outn

.param linelength_out = 20	$ output line length in inches
xolinep op outp vtto ad8158_lineloss linelength=linelength_out
xolinen on outn vtto ad8158_lineloss linelength=linelength_out

*
* Options used to control accuracy of simulation

.option post list
.option parhier = local
.option numdgt=9 tnom=27
.option dccap post=ascii ingold=2
.option pivot gmin=1e-9 gmax=1e6
.option ACCURATE=1
.option TIMERES = 0.1p VNTOL=5
.option METHOD=GEAR
.option LVLTIM=3
.option CSHUNT=0.1f
.temperature 27
.tran 0.1p 8n
.options post=ascii chgtol=1e-20 reltol=1e-8

* *********************************************
* Global parameter used to set AD8158 RX & TX
* Do not change variable names
* *********************************************

.param ad8158_eq_setting = 0      $ {Relative EQ setting, 0:9 for I2C}
				  $ {Settings 0,2,4,9 for pin control}
.param ad8158_pe_boost = 2.0	  $ {Data Sheet: Pp 24-25, Table 20, column 5, Linear Boost Factor }
				  $ {1=no boost, 2=factor of 2 boost, ie. 6.02 dB)
.param ad8158_tx_olev = 16m       $ {4m/8m/12m/16m/24m .. "dc level" output current}
				  $ {24m = 24 milliamps, corresponds to 1200mVppd output level or Vod = 600mVd}
				  $ {16m = 16 milliamps, corresponds to  800mVppd output level or Vod = 400mVd}	
				  $ {12m = 12 milliamps, corresponds to  600mVppd output level or Vod = 300mVd}
				  $ { 8m =  8 milliamps, corresponds to  400mVppd output level or Vod = 200mVd}
				  $ 
				  $ {Example:  800mVppd/50 Ohm_diff = 16mA}

.param ad8158_sel4g = 0           $ {0/1 -- Peak PE boost at 6.5g [ad8158_sel4g=0] or 4.25g [ad8158_sel4g=1]}

.end
